==> ixa-pipe-ml-0.0.2-sources.jar: eus/ixa/ixa/pipe/ml/features/SentenceFeatureGenerator.java <==
/*
 * Copyright 2014 Rodrigo Agerri

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
 */
package eus.ixa.ixa.pipe.ml.features;

import java.util.List;
import java.util.Map;

import opennlp.tools.util.featuregen.CustomFeatureGenerator;
import opennlp.tools.util.featuregen.FeatureGeneratorResourceProvider;

public class SentenceFeatureGenerator extends CustomFeatureGenerator {

  private Map<String, String> properties;

  public SentenceFeatureGenerator() {
  }

  public void createFeatures(List<String> features, String[] tokens, int index,
      String[] previousOutcomes) {

    if (properties.get("begin").equalsIgnoreCase("true") && index == 0) {
      features.add("S=begin");
    }

    if (properties.get("end").equalsIgnoreCase("true") && tokens.length == index + 1) {
      features.add("S=end");
    }
  }

  public void init(Map<String, String> attributes, FeatureGeneratorResourceProvider resourceProvider) {
    this.properties = attributes;
  }


  @Override
  public void updateAdaptiveData(String[] tokens, String[] outcomes) {

  }

  @Override
  public void clearAdaptiveData() {

  }

}

==> ixa-pipe-ml-0.0.5-sources.jar: eus/ixa/ixa/pipe/ml/features/SentenceFeatureGenerator.java <==
/*
 * Copyright 2014 Rodrigo Agerri

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
 */
package eus.ixa.ixa.pipe.ml.features;

import java.util.List;
import java.util.Map;

import opennlp.tools.util.featuregen.CustomFeatureGenerator;
import opennlp.tools.util.featuregen.FeatureGeneratorResourceProvider;

public class SentenceFeatureGenerator extends CustomFeatureGenerator {

  private Map<String, String> properties;

  public SentenceFeatureGenerator() {
  }

  @Override
  public void createFeatures(final List<String> features, final String[] tokens,
      final int index, final String[] previousOutcomes) {

    if (this.properties.get("begin").equalsIgnoreCase("true") && index == 0) {
      features.add("S=begin");
    }

    if (this.properties.get("end").equalsIgnoreCase("true")
        && tokens.length == index + 1) {
      features.add("S=end");
    }
  }

  @Override
  public void init(final Map<String, String> attributes,
      final FeatureGeneratorResourceProvider resourceProvider) {
    this.properties = attributes;
  }

  @Override
  public void updateAdaptiveData(final String[] tokens,
      final String[] outcomes) {

  }

  @Override
  public void clearAdaptiveData() {

  }

}
